@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2006 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2010 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -81,7 +81,7 @@ public class CleanUpActivator implements BundleActivator {
         whiteboard = new Whiteboard(context);
         final ContextService contexts = whiteboard.getService(ContextService.class);
 
-        final EntityCleanUp entityCleanUp = new EntityCleanUp(AbstractPublicationService.STORAGE);
+        final EntityCleanUp entityCleanUp = new EntityCleanUp(AbstractPublicationService.getDefaultStorage());
         
         registrations = new LinkedList<ServiceRegistration>();
 
