@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2006 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2010 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -67,7 +67,7 @@ public class DeleteEventListenerActivator implements BundleActivator {
     private ServiceRegistration serviceRegistration;
 
     public void start(final BundleContext context) throws Exception {
-        final PublicationStorage storage = AbstractPublicationService.STORAGE;
+        final PublicationStorage storage = AbstractPublicationService.getDefaultStorage();
         final PublicationUserDeleteListener listener = new PublicationUserDeleteListener();
         listener.setStorage(storage);
         serviceRegistration = context.registerService(DeleteListener.class.getName(), listener, null);
