@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2006 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2010 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -103,6 +103,10 @@ public class SimContactSQLInterface implements ContactSQLInterface {
 
     }
 
+    public void updateUserContact(Contact contact, Date lastmodified) throws OXException {
+        // Nothing to do.
+    }
+
     /*
      * (non-Javadoc)
      * @see
